You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@activemq.apache.org by cl...@apache.org on 2015/04/28 18:02:48 UTC

[43/57] [abbrv] [partial] activemq-6 git commit: ACTIVEMQ6-1 Artemis rename

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/SizeFormatterUtil.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/SizeFormatterUtil.java b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/SizeFormatterUtil.java
index a8ad321..b112f40 100644
--- a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/SizeFormatterUtil.java
+++ b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/SizeFormatterUtil.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.utils;
+package org.apache.activemq.artemis.utils;
 
 public class SizeFormatterUtil
 {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/SoftValueHashMap.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/SoftValueHashMap.java b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/SoftValueHashMap.java
index 00a1474..1784eb3 100644
--- a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/SoftValueHashMap.java
+++ b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/SoftValueHashMap.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.utils;
+package org.apache.activemq.artemis.utils;
 
 import java.lang.ref.ReferenceQueue;
 import java.lang.ref.SoftReference;
@@ -28,7 +28,7 @@ import java.util.Set;
 import java.util.TreeSet;
 import java.util.concurrent.atomic.AtomicLong;
 
-import org.apache.activemq.core.client.ActiveMQClientLogger;
+import org.apache.activemq.artemis.core.client.ActiveMQClientLogger;
 
 public class SoftValueHashMap<K, V extends SoftValueHashMap.ValueCache> implements Map<K, V>
 {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/TimeAndCounterIDGenerator.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/TimeAndCounterIDGenerator.java b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/TimeAndCounterIDGenerator.java
index 318bcab..59cbe55 100644
--- a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/TimeAndCounterIDGenerator.java
+++ b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/TimeAndCounterIDGenerator.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.utils;
+package org.apache.activemq.artemis.utils;
 
 import java.util.concurrent.atomic.AtomicLong;
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/TokenBucketLimiter.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/TokenBucketLimiter.java b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/TokenBucketLimiter.java
index 2934f8d..0c3b703 100644
--- a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/TokenBucketLimiter.java
+++ b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/TokenBucketLimiter.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.utils;
+package org.apache.activemq.artemis.utils;
 
 /**
  * This class can throttle to a specific rate, using an algorithm based on the <a

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/TokenBucketLimiterImpl.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/TokenBucketLimiterImpl.java b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/TokenBucketLimiterImpl.java
index f0f1415..f080952 100644
--- a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/TokenBucketLimiterImpl.java
+++ b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/TokenBucketLimiterImpl.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.utils;
+package org.apache.activemq.artemis.utils;
 
 import java.util.concurrent.TimeUnit;
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/VersionLoader.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/VersionLoader.java b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/VersionLoader.java
index 05529d3..a8bffac 100644
--- a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/VersionLoader.java
+++ b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/VersionLoader.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.utils;
+package org.apache.activemq.artemis.utils;
 
 import java.io.IOException;
 import java.io.InputStream;
@@ -29,9 +29,9 @@ import java.util.List;
 import java.util.Properties;
 import java.util.StringTokenizer;
 
-import org.apache.activemq.core.client.ActiveMQClientLogger;
-import org.apache.activemq.core.version.Version;
-import org.apache.activemq.core.version.impl.VersionImpl;
+import org.apache.activemq.artemis.core.client.ActiveMQClientLogger;
+import org.apache.activemq.artemis.core.version.Version;
+import org.apache.activemq.artemis.core.version.impl.VersionImpl;
 
 /**
  * This loads the version info in from a version.properties file.

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/XMLUtil.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/XMLUtil.java b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/XMLUtil.java
index 3a4eb1c..eb620c2 100644
--- a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/XMLUtil.java
+++ b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/XMLUtil.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.utils;
+package org.apache.activemq.artemis.utils;
 
 import javax.xml.XMLConstants;
 import javax.xml.parsers.DocumentBuilder;
@@ -33,8 +33,8 @@ import java.security.PrivilegedAction;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.activemq.core.client.ActiveMQClientLogger;
-import org.apache.activemq.core.client.ActiveMQClientMessageBundle;
+import org.apache.activemq.artemis.core.client.ActiveMQClientLogger;
+import org.apache.activemq.artemis.core.client.ActiveMQClientMessageBundle;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.NamedNodeMap;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/XidCodecSupport.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/XidCodecSupport.java b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/XidCodecSupport.java
index 5a256aa..14b8fa4 100644
--- a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/XidCodecSupport.java
+++ b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/XidCodecSupport.java
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.utils;
+package org.apache.activemq.artemis.utils;
 
 import javax.transaction.xa.Xid;
 
-import org.apache.activemq.api.core.ActiveMQBuffer;
-import org.apache.activemq.core.transaction.impl.XidImpl;
+import org.apache.activemq.artemis.api.core.ActiveMQBuffer;
+import org.apache.activemq.artemis.core.transaction.impl.XidImpl;
 
 public class XidCodecSupport
 {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONArray.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONArray.java b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONArray.java
index 528d42c..4e971be 100644
--- a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONArray.java
+++ b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONArray.java
@@ -21,7 +21,7 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 */
-package org.apache.activemq.utils.json;
+package org.apache.activemq.artemis.utils.json;
 
 import java.io.IOException;
 import java.io.Writer;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONException.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONException.java b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONException.java
index b9f74c9..12232d5 100644
--- a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONException.java
+++ b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONException.java
@@ -21,7 +21,7 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 */
-package org.apache.activemq.utils.json;
+package org.apache.activemq.artemis.utils.json;
 
 /**
  * The JSONException is thrown by the JSON.org classes then things are amiss.

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONObject.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONObject.java b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONObject.java
index 88ae5d2..441c8ce 100644
--- a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONObject.java
+++ b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONObject.java
@@ -21,7 +21,7 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 */
-package org.apache.activemq.utils.json;
+package org.apache.activemq.artemis.utils.json;
 
 import java.io.IOException;
 import java.io.Writer;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONString.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONString.java b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONString.java
index 407c514..679ec16 100644
--- a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONString.java
+++ b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONString.java
@@ -21,7 +21,7 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 */
-package org.apache.activemq.utils.json;
+package org.apache.activemq.artemis.utils.json;
 
 /**
  * The <code>JSONString</code> interface allows a <code>toJSONString()</code>

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONTokener.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONTokener.java b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONTokener.java
index f1b93b3..88b1e03 100644
--- a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONTokener.java
+++ b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/json/JSONTokener.java
@@ -21,7 +21,7 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 */
-package org.apache.activemq.utils.json;
+package org.apache.activemq.artemis.utils.json;
 
 import java.io.BufferedReader;
 import java.io.IOException;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/package-info.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/package-info.java b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/package-info.java
index f755139..4c50f81 100644
--- a/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/package-info.java
+++ b/artemis-core-client/src/main/java/org/apache/activemq/artemis/utils/package-info.java
@@ -14,5 +14,5 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.utils;
+package org.apache.activemq.artemis.utils;
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-core-client/src/test/java/org/apache/activemq/artemis/tests/CoreUnitTestCase.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/test/java/org/apache/activemq/artemis/tests/CoreUnitTestCase.java b/artemis-core-client/src/test/java/org/apache/activemq/artemis/tests/CoreUnitTestCase.java
index 2d020f4..3bdc561 100644
--- a/artemis-core-client/src/test/java/org/apache/activemq/artemis/tests/CoreUnitTestCase.java
+++ b/artemis-core-client/src/test/java/org/apache/activemq/artemis/tests/CoreUnitTestCase.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.tests;
+package org.apache.activemq.artemis.tests;
 
 
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.TimeUnit;
 
-import org.apache.activemq.core.client.ActiveMQClientLogger;
+import org.apache.activemq.artemis.core.client.ActiveMQClientLogger;
 import org.junit.Assert;
 import org.junit.Rule;
 import org.junit.rules.TestRule;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-core-client/src/test/java/org/apache/activemq/artemis/tests/util/RandomUtil.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/test/java/org/apache/activemq/artemis/tests/util/RandomUtil.java b/artemis-core-client/src/test/java/org/apache/activemq/artemis/tests/util/RandomUtil.java
index bbe6378..25e68c9 100644
--- a/artemis-core-client/src/test/java/org/apache/activemq/artemis/tests/util/RandomUtil.java
+++ b/artemis-core-client/src/test/java/org/apache/activemq/artemis/tests/util/RandomUtil.java
@@ -14,16 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.tests.util;
+package org.apache.activemq.artemis.tests.util;
 
 import javax.transaction.xa.Xid;
 import java.util.Random;
 import java.util.UUID;
 
-import org.apache.activemq.api.core.ActiveMQBuffer;
-import org.apache.activemq.api.core.ActiveMQBuffers;
-import org.apache.activemq.api.core.SimpleString;
-import org.apache.activemq.core.transaction.impl.XidImpl;
+import org.apache.activemq.artemis.api.core.ActiveMQBuffer;
+import org.apache.activemq.artemis.api.core.ActiveMQBuffers;
+import org.apache.activemq.artemis.api.core.SimpleString;
+import org.apache.activemq.artemis.core.transaction.impl.XidImpl;
 
 public final class RandomUtil
 {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-core-client/src/test/java/org/apache/activemq/artemis/tests/util/SilentTestCase.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/test/java/org/apache/activemq/artemis/tests/util/SilentTestCase.java b/artemis-core-client/src/test/java/org/apache/activemq/artemis/tests/util/SilentTestCase.java
index 1671e13..952a2c9 100644
--- a/artemis-core-client/src/test/java/org/apache/activemq/artemis/tests/util/SilentTestCase.java
+++ b/artemis-core-client/src/test/java/org/apache/activemq/artemis/tests/util/SilentTestCase.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.tests.util;
+package org.apache.activemq.artemis.tests.util;
 import org.junit.Before;
 import org.junit.After;
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/CompressionUtilTest.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/CompressionUtilTest.java b/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/CompressionUtilTest.java
index e83acf3..98bc9c9 100644
--- a/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/CompressionUtilTest.java
+++ b/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/CompressionUtilTest.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.util;
+package org.apache.activemq.artemis.util;
 
 import org.junit.Test;
 
@@ -27,9 +27,9 @@ import java.util.zip.Deflater;
 
 import org.junit.Assert;
 
-import org.apache.activemq.utils.DeflaterReader;
-import org.apache.activemq.utils.InflaterReader;
-import org.apache.activemq.utils.InflaterWriter;
+import org.apache.activemq.artemis.utils.DeflaterReader;
+import org.apache.activemq.artemis.utils.InflaterReader;
+import org.apache.activemq.artemis.utils.InflaterWriter;
 
 public class CompressionUtilTest extends Assert
 {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/ConcurrentHashSetTest.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/ConcurrentHashSetTest.java b/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/ConcurrentHashSetTest.java
index 288ec91..d10e432 100644
--- a/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/ConcurrentHashSetTest.java
+++ b/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/ConcurrentHashSetTest.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.util;
+package org.apache.activemq.artemis.util;
 import org.junit.Before;
 import org.junit.After;
 
@@ -25,9 +25,9 @@ import java.util.Iterator;
 import org.junit.Assert;
 
 
-import org.apache.activemq.tests.util.RandomUtil;
-import org.apache.activemq.utils.ConcurrentHashSet;
-import org.apache.activemq.utils.ConcurrentSet;
+import org.apache.activemq.artemis.tests.util.RandomUtil;
+import org.apache.activemq.artemis.utils.ConcurrentHashSet;
+import org.apache.activemq.artemis.utils.ConcurrentSet;
 
 public class ConcurrentHashSetTest extends Assert
 {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/TimeAndCounterIDGeneratorTest.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/TimeAndCounterIDGeneratorTest.java b/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/TimeAndCounterIDGeneratorTest.java
index e09e486..d97fafc 100644
--- a/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/TimeAndCounterIDGeneratorTest.java
+++ b/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/TimeAndCounterIDGeneratorTest.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.util;
+package org.apache.activemq.artemis.util;
 
 import org.junit.Test;
 
@@ -23,9 +23,9 @@ import java.util.concurrent.CountDownLatch;
 import org.junit.Assert;
 
 
-import org.apache.activemq.tests.CoreUnitTestCase;
-import org.apache.activemq.utils.ConcurrentHashSet;
-import org.apache.activemq.utils.TimeAndCounterIDGenerator;
+import org.apache.activemq.artemis.tests.CoreUnitTestCase;
+import org.apache.activemq.artemis.utils.ConcurrentHashSet;
+import org.apache.activemq.artemis.utils.TimeAndCounterIDGenerator;
 
 public class TimeAndCounterIDGeneratorTest extends Assert
 {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/TypedPropertiesConversionTest.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/TypedPropertiesConversionTest.java b/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/TypedPropertiesConversionTest.java
index d1fd668..df92491 100644
--- a/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/TypedPropertiesConversionTest.java
+++ b/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/TypedPropertiesConversionTest.java
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.util;
-import org.apache.activemq.api.core.ActiveMQPropertyConversionException;
-import org.apache.activemq.api.core.SimpleString;
-import org.apache.activemq.tests.util.RandomUtil;
-import org.apache.activemq.utils.TypedProperties;
+package org.apache.activemq.artemis.util;
+import org.apache.activemq.artemis.api.core.ActiveMQPropertyConversionException;
+import org.apache.activemq.artemis.api.core.SimpleString;
+import org.apache.activemq.artemis.tests.util.RandomUtil;
+import org.apache.activemq.artemis.utils.TypedProperties;
 import org.junit.After;
 import org.junit.Assert;
 import org.junit.Before;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/TypedPropertiesTest.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/TypedPropertiesTest.java b/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/TypedPropertiesTest.java
index 99cb415..e53be96 100644
--- a/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/TypedPropertiesTest.java
+++ b/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/TypedPropertiesTest.java
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.util;
+package org.apache.activemq.artemis.util;
 import java.util.Iterator;
 
-import org.apache.activemq.api.core.ActiveMQBuffer;
-import org.apache.activemq.api.core.ActiveMQBuffers;
-import org.apache.activemq.api.core.SimpleString;
-import org.apache.activemq.tests.util.RandomUtil;
-import org.apache.activemq.utils.TypedProperties;
+import org.apache.activemq.artemis.api.core.ActiveMQBuffer;
+import org.apache.activemq.artemis.api.core.ActiveMQBuffers;
+import org.apache.activemq.artemis.api.core.SimpleString;
+import org.apache.activemq.artemis.tests.util.RandomUtil;
+import org.apache.activemq.artemis.utils.TypedProperties;
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/XMLUtilTest.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/XMLUtilTest.java b/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/XMLUtilTest.java
index d84ff3a..594bd02 100644
--- a/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/XMLUtilTest.java
+++ b/artemis-core-client/src/test/java/org/apache/activemq/artemis/util/XMLUtilTest.java
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.util;
+package org.apache.activemq.artemis.util;
 
 import org.junit.Test;
 
 import org.junit.Assert;
 
-import org.apache.activemq.tests.util.SilentTestCase;
-import org.apache.activemq.utils.XMLUtil;
+import org.apache.activemq.artemis.tests.util.SilentTestCase;
+import org.apache.activemq.artemis.utils.XMLUtil;
 import org.w3c.dom.Element;
 import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;
@@ -37,9 +37,9 @@ public class XMLUtilTest extends SilentTestCase
    {
       String document = "<blah>foo</blah>";
 
-      Element e = org.apache.activemq.utils.XMLUtil.stringToElement(document);
+      Element e = XMLUtil.stringToElement(document);
 
-      Assert.assertEquals("foo", org.apache.activemq.utils.XMLUtil.getTextContent(e));
+      Assert.assertEquals("foo", XMLUtil.getTextContent(e));
    }
 
    @Test
@@ -49,7 +49,7 @@ public class XMLUtilTest extends SilentTestCase
 
       Element e = XMLUtil.stringToElement(document);
 
-      Assert.assertEquals("foo", org.apache.activemq.utils.XMLUtil.getTextContent(e));
+      Assert.assertEquals("foo", XMLUtil.getTextContent(e));
    }
 
    @Test
@@ -57,11 +57,11 @@ public class XMLUtilTest extends SilentTestCase
    {
       String document = "<blah someattribute=\"somevalue\"><a/></blah>";
 
-      Element e = org.apache.activemq.utils.XMLUtil.stringToElement(document);
+      Element e = XMLUtil.stringToElement(document);
 
-      String s = org.apache.activemq.utils.XMLUtil.getTextContent(e);
+      String s = XMLUtil.getTextContent(e);
 
-      Element subelement = org.apache.activemq.utils.XMLUtil.stringToElement(s);
+      Element subelement = XMLUtil.stringToElement(s);
 
       Assert.assertEquals("a", subelement.getNodeName());
    }
@@ -71,11 +71,11 @@ public class XMLUtilTest extends SilentTestCase
    {
       String document = "<blah someattribute=\"somevalue\"><a></a></blah>";
 
-      Element e = org.apache.activemq.utils.XMLUtil.stringToElement(document);
+      Element e = XMLUtil.stringToElement(document);
 
-      String s = org.apache.activemq.utils.XMLUtil.getTextContent(e);
+      String s = XMLUtil.getTextContent(e);
 
-      Element subelement = org.apache.activemq.utils.XMLUtil.stringToElement(s);
+      Element subelement = XMLUtil.stringToElement(s);
 
       Assert.assertEquals("a", subelement.getNodeName());
    }
@@ -85,11 +85,11 @@ public class XMLUtilTest extends SilentTestCase
    {
       String document = "<blah someattribute=\"somevalue\"><a><b/></a></blah>";
 
-      Element e = org.apache.activemq.utils.XMLUtil.stringToElement(document);
+      Element e = XMLUtil.stringToElement(document);
 
-      String s = org.apache.activemq.utils.XMLUtil.getTextContent(e);
+      String s = XMLUtil.getTextContent(e);
 
-      Element subelement = org.apache.activemq.utils.XMLUtil.stringToElement(s);
+      Element subelement = XMLUtil.stringToElement(s);
 
       Assert.assertEquals("a", subelement.getNodeName());
       NodeList nl = subelement.getChildNodes();
@@ -113,7 +113,7 @@ public class XMLUtilTest extends SilentTestCase
       String s = "<a/>";
       String s2 = "<a/>";
 
-      XMLUtil.assertEquivalent(XMLUtil.stringToElement(s), org.apache.activemq.utils.XMLUtil.stringToElement(s2));
+      XMLUtil.assertEquivalent(XMLUtil.stringToElement(s), XMLUtil.stringToElement(s2));
    }
 
    @Test
@@ -122,7 +122,7 @@ public class XMLUtilTest extends SilentTestCase
       String s = "<a></a>";
       String s2 = "<a/>";
 
-      XMLUtil.assertEquivalent(XMLUtil.stringToElement(s), org.apache.activemq.utils.XMLUtil.stringToElement(s2));
+      XMLUtil.assertEquivalent(XMLUtil.stringToElement(s), XMLUtil.stringToElement(s2));
    }
 
    @Test
@@ -133,8 +133,8 @@ public class XMLUtilTest extends SilentTestCase
 
       try
       {
-         org.apache.activemq.utils.XMLUtil.assertEquivalent(org.apache.activemq.utils.XMLUtil.stringToElement(s),
-                                                    XMLUtil.stringToElement(s2));
+         XMLUtil.assertEquivalent(XMLUtil.stringToElement(s),
+                 XMLUtil.stringToElement(s2));
          Assert.fail("this should throw exception");
       }
       catch (IllegalArgumentException e)
@@ -149,8 +149,8 @@ public class XMLUtilTest extends SilentTestCase
       String s = "<a attr1=\"val1\" attr2=\"val2\"/>";
       String s2 = "<a attr2=\"val2\" attr1=\"val1\"/>";
 
-      org.apache.activemq.utils.XMLUtil.assertEquivalent(org.apache.activemq.utils.XMLUtil.stringToElement(s),
-                                                 org.apache.activemq.utils.XMLUtil.stringToElement(s2));
+      XMLUtil.assertEquivalent(XMLUtil.stringToElement(s),
+              XMLUtil.stringToElement(s2));
    }
 
    @Test
@@ -159,8 +159,8 @@ public class XMLUtilTest extends SilentTestCase
       String s = "<a><b/></a>";
       String s2 = "<a><b/></a>";
 
-      org.apache.activemq.utils.XMLUtil.assertEquivalent(org.apache.activemq.utils.XMLUtil.stringToElement(s),
-                                                 org.apache.activemq.utils.XMLUtil.stringToElement(s2));
+      XMLUtil.assertEquivalent(XMLUtil.stringToElement(s),
+              XMLUtil.stringToElement(s2));
    }
 
    @Test
@@ -169,8 +169,8 @@ public class XMLUtilTest extends SilentTestCase
       String s = "<enclosing><a attr1=\"val1\" attr2=\"val2\"/></enclosing>";
       String s2 = "<enclosing><a attr2=\"val2\" attr1=\"val1\"/></enclosing>";
 
-      org.apache.activemq.utils.XMLUtil.assertEquivalent(XMLUtil.stringToElement(s),
-                                                 org.apache.activemq.utils.XMLUtil.stringToElement(s2));
+      XMLUtil.assertEquivalent(XMLUtil.stringToElement(s),
+              XMLUtil.stringToElement(s2));
    }
 
    @Test
@@ -181,8 +181,8 @@ public class XMLUtilTest extends SilentTestCase
 
       try
       {
-         org.apache.activemq.utils.XMLUtil.assertEquivalent(org.apache.activemq.utils.XMLUtil.stringToElement(s),
-                                                    org.apache.activemq.utils.XMLUtil.stringToElement(s2));
+         XMLUtil.assertEquivalent(XMLUtil.stringToElement(s),
+                 XMLUtil.stringToElement(s2));
          Assert.fail("this should throw exception");
       }
       catch (IllegalArgumentException e)
@@ -198,25 +198,25 @@ public class XMLUtilTest extends SilentTestCase
       String s = "<a><!-- some comment --><b/><!--some other comment --><c/><!-- blah --></a>";
       String s2 = "<a><b/><!--blah blah--><c/></a>";
 
-      org.apache.activemq.utils.XMLUtil.assertEquivalent(XMLUtil.stringToElement(s),
-                                                 org.apache.activemq.utils.XMLUtil.stringToElement(s2));
+      XMLUtil.assertEquivalent(XMLUtil.stringToElement(s),
+              XMLUtil.stringToElement(s2));
    }
 
    @Test
    public void testElementToString_1() throws Exception
    {
       String s = "<a b=\"something\">somethingelse</a>";
-      Element e = org.apache.activemq.utils.XMLUtil.stringToElement(s);
-      String tostring = org.apache.activemq.utils.XMLUtil.elementToString(e);
-      Element convertedAgain = org.apache.activemq.utils.XMLUtil.stringToElement(tostring);
-      org.apache.activemq.utils.XMLUtil.assertEquivalent(e, convertedAgain);
+      Element e = XMLUtil.stringToElement(s);
+      String tostring = XMLUtil.elementToString(e);
+      Element convertedAgain = XMLUtil.stringToElement(tostring);
+      XMLUtil.assertEquivalent(e, convertedAgain);
    }
 
    @Test
    public void testElementToString_2() throws Exception
    {
       String s = "<a b=\"something\"></a>";
-      Element e = org.apache.activemq.utils.XMLUtil.stringToElement(s);
+      Element e = XMLUtil.stringToElement(s);
       String tostring = XMLUtil.elementToString(e);
       Element convertedAgain = XMLUtil.stringToElement(tostring);
       XMLUtil.assertEquivalent(e, convertedAgain);
@@ -226,20 +226,20 @@ public class XMLUtilTest extends SilentTestCase
    public void testElementToString_3() throws Exception
    {
       String s = "<a b=\"something\"/>";
-      Element e = org.apache.activemq.utils.XMLUtil.stringToElement(s);
+      Element e = XMLUtil.stringToElement(s);
       String tostring = XMLUtil.elementToString(e);
-      Element convertedAgain = org.apache.activemq.utils.XMLUtil.stringToElement(tostring);
-      org.apache.activemq.utils.XMLUtil.assertEquivalent(e, convertedAgain);
+      Element convertedAgain = XMLUtil.stringToElement(tostring);
+      XMLUtil.assertEquivalent(e, convertedAgain);
    }
 
    @Test
    public void testElementToString_4() throws Exception
    {
       String s = "<a><![CDATA[somedata]]></a>";
-      Element e = org.apache.activemq.utils.XMLUtil.stringToElement(s);
+      Element e = XMLUtil.stringToElement(s);
       String tostring = XMLUtil.elementToString(e);
-      Element convertedAgain = org.apache.activemq.utils.XMLUtil.stringToElement(tostring);
-      org.apache.activemq.utils.XMLUtil.assertEquivalent(e, convertedAgain);
+      Element convertedAgain = XMLUtil.stringToElement(tostring);
+      XMLUtil.assertEquivalent(e, convertedAgain);
    }
 
    @Test
@@ -261,7 +261,7 @@ public class XMLUtilTest extends SilentTestCase
                      + "</configuration>";
       System.setProperty("sysprop1", "test1");
       System.setProperty("sysprop2", "content4");
-      String replaced = org.apache.activemq.utils.XMLUtil.replaceSystemProps(before);
+      String replaced = XMLUtil.replaceSystemProps(before);
       Assert.assertEquals(after, replaced);
    }
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-dto/pom.xml
----------------------------------------------------------------------
diff --git a/artemis-dto/pom.xml b/artemis-dto/pom.xml
index 118f355..69888fd 100644
--- a/artemis-dto/pom.xml
+++ b/artemis-dto/pom.xml
@@ -19,11 +19,11 @@
 
    <parent>
       <groupId>org.apache.activemq</groupId>
-      <artifactId>activemq-pom</artifactId>
-      <version>10.0.0-SNAPSHOT</version>
+      <artifactId>artemis-pom</artifactId>
+      <version>1.0.0-SNAPSHOT</version>
    </parent>
 
-   <artifactId>activemq-dto</artifactId>
+   <artifactId>artemis-dto</artifactId>
    <packaging>jar</packaging>
    <name>ActiveMQ Artemis DTO</name>
 
@@ -34,7 +34,7 @@
    <dependencies>
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-commons</artifactId>
+         <artifactId>artemis-commons</artifactId>
          <version>${project.version}</version>
       </dependency>
    </dependencies>

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/AppDTO.java
----------------------------------------------------------------------
diff --git a/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/AppDTO.java b/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/AppDTO.java
index 5d1e043..72bb470 100644
--- a/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/AppDTO.java
+++ b/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/AppDTO.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.dto;
+package org.apache.activemq.artemis.dto;
 
 
 import javax.xml.bind.annotation.XmlAccessType;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/BasicSecurityDTO.java
----------------------------------------------------------------------
diff --git a/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/BasicSecurityDTO.java b/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/BasicSecurityDTO.java
index ee528ee..f11c2d6 100644
--- a/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/BasicSecurityDTO.java
+++ b/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/BasicSecurityDTO.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.dto;
+package org.apache.activemq.artemis.dto;
 
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/BrokerDTO.java
----------------------------------------------------------------------
diff --git a/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/BrokerDTO.java b/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/BrokerDTO.java
index a11d6b8..ea14d87 100644
--- a/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/BrokerDTO.java
+++ b/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/BrokerDTO.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.dto;
+package org.apache.activemq.artemis.dto;
 
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/ComponentDTO.java
----------------------------------------------------------------------
diff --git a/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/ComponentDTO.java b/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/ComponentDTO.java
index 8fd9868..b58d89c 100644
--- a/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/ComponentDTO.java
+++ b/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/ComponentDTO.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.dto;
+package org.apache.activemq.artemis.dto;
 
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/SecurityDTO.java
----------------------------------------------------------------------
diff --git a/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/SecurityDTO.java b/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/SecurityDTO.java
index 723f92d..e4308d4 100644
--- a/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/SecurityDTO.java
+++ b/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/SecurityDTO.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.dto;
+package org.apache.activemq.artemis.dto;
 
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/ServerDTO.java
----------------------------------------------------------------------
diff --git a/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/ServerDTO.java b/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/ServerDTO.java
index 9ef2168..0595dab 100644
--- a/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/ServerDTO.java
+++ b/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/ServerDTO.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.dto;
+package org.apache.activemq.artemis.dto;
 
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/WebServerDTO.java
----------------------------------------------------------------------
diff --git a/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/WebServerDTO.java b/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/WebServerDTO.java
index 5875ac4..78ecbf9 100644
--- a/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/WebServerDTO.java
+++ b/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/WebServerDTO.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.dto;
+package org.apache.activemq.artemis.dto;
 
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
@@ -38,6 +38,6 @@ public class WebServerDTO extends ComponentDTO
 
    public WebServerDTO()
    {
-      componentClassName = "org.apache.activemq.component.WebServerComponent";
+      componentClassName = "org.apache.activemq.artemis.component.WebServerComponent";
    }
 }

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/XmlUtil.java
----------------------------------------------------------------------
diff --git a/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/XmlUtil.java b/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/XmlUtil.java
index 5f9db1f..7596cb3 100644
--- a/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/XmlUtil.java
+++ b/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/XmlUtil.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.dto;
+package org.apache.activemq.artemis.dto;
 
 import javax.xml.XMLConstants;
 import javax.xml.bind.JAXBContext;
@@ -86,7 +86,7 @@ public class XmlUtil
 
    public static <T> T decode(Class<T> clazz, File configuration) throws Exception
    {
-      JAXBContext jaxbContext = JAXBContext.newInstance("org.apache.activemq.dto");
+      JAXBContext jaxbContext = JAXBContext.newInstance("org.apache.activemq.artemis.dto");
 
       Unmarshaller unmarshaller = jaxbContext.createUnmarshaller();
       SchemaFactory sf = SchemaFactory.newInstance(XMLConstants.W3C_XML_SCHEMA_NS_URI);

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/package-info.java
----------------------------------------------------------------------
diff --git a/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/package-info.java b/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/package-info.java
index cb303af..7752e27 100644
--- a/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/package-info.java
+++ b/artemis-dto/src/main/java/org/apache/activemq/artemis/dto/package-info.java
@@ -20,4 +20,4 @@
 @javax.xml.bind.annotation.XmlSchema(
         namespace = "http://activemq.org/schema",
         elementFormDefault = javax.xml.bind.annotation.XmlNsForm.QUALIFIED)
-package org.apache.activemq.dto;
+package org.apache.activemq.artemis.dto;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-jms-client/pom.xml
----------------------------------------------------------------------
diff --git a/artemis-jms-client/pom.xml b/artemis-jms-client/pom.xml
index e683ecb..e448927 100644
--- a/artemis-jms-client/pom.xml
+++ b/artemis-jms-client/pom.xml
@@ -19,11 +19,11 @@
 
    <parent>
       <groupId>org.apache.activemq</groupId>
-      <artifactId>activemq-pom</artifactId>
-      <version>10.0.0-SNAPSHOT</version>
+      <artifactId>artemis-pom</artifactId>
+      <version>1.0.0-SNAPSHOT</version>
    </parent>
 
-   <artifactId>activemq-jms-client</artifactId>
+   <artifactId>artemis-jms-client</artifactId>
    <packaging>jar</packaging>
    <name>ActiveMQ Artemis JMS Client</name>
 
@@ -40,14 +40,14 @@
       </dependency>
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-core-client</artifactId>
+         <artifactId>artemis-core-client</artifactId>
          <version>${project.version}</version>
          <scope>test</scope>
          <type>test-jar</type>
       </dependency>
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-core-client</artifactId>
+         <artifactId>artemis-core-client</artifactId>
          <version>${project.version}</version>
       </dependency>
       <dependency>
@@ -82,7 +82,7 @@
                      <maxmemory>512m</maxmemory>
                      <quiet>false</quiet>
                      <aggregate>true</aggregate>
-                     <excludePackageNames>org.apache.activemq.core:org.apache.activemq.utils</excludePackageNames>
+                     <excludePackageNames>org.apache.activemq.artemis.core:org.apache.activemq.artemis.utils</excludePackageNames>
                   </configuration>
                   <executions>
                      <execution>

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/ActiveMQJMSClient.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/ActiveMQJMSClient.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/ActiveMQJMSClient.java
index 3e763b9..0ce6e81 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/ActiveMQJMSClient.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/ActiveMQJMSClient.java
@@ -14,22 +14,22 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.api.jms;
+package org.apache.activemq.artemis.api.jms;
 
 import javax.jms.Queue;
 import javax.jms.Topic;
 
-import org.apache.activemq.api.core.DiscoveryGroupConfiguration;
-import org.apache.activemq.api.core.TransportConfiguration;
-import org.apache.activemq.jms.client.ActiveMQConnectionFactory;
-import org.apache.activemq.jms.client.ActiveMQDestination;
-import org.apache.activemq.jms.client.ActiveMQJMSConnectionFactory;
-import org.apache.activemq.jms.client.ActiveMQQueueConnectionFactory;
-import org.apache.activemq.jms.client.ActiveMQTopicConnectionFactory;
-import org.apache.activemq.jms.client.ActiveMQXAConnectionFactory;
-import org.apache.activemq.jms.client.ActiveMQXAQueueConnectionFactory;
-import org.apache.activemq.jms.client.ActiveMQXATopicConnectionFactory;
-import org.apache.activemq.uri.ConnectionFactoryParser;
+import org.apache.activemq.artemis.api.core.DiscoveryGroupConfiguration;
+import org.apache.activemq.artemis.api.core.TransportConfiguration;
+import org.apache.activemq.artemis.jms.client.ActiveMQConnectionFactory;
+import org.apache.activemq.artemis.jms.client.ActiveMQDestination;
+import org.apache.activemq.artemis.jms.client.ActiveMQJMSConnectionFactory;
+import org.apache.activemq.artemis.jms.client.ActiveMQQueueConnectionFactory;
+import org.apache.activemq.artemis.jms.client.ActiveMQTopicConnectionFactory;
+import org.apache.activemq.artemis.jms.client.ActiveMQXAConnectionFactory;
+import org.apache.activemq.artemis.jms.client.ActiveMQXAQueueConnectionFactory;
+import org.apache.activemq.artemis.jms.client.ActiveMQXATopicConnectionFactory;
+import org.apache.activemq.artemis.uri.ConnectionFactoryParser;
 
 /**
  * A utility class for creating ActiveMQ client-side JMS managed resources.

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/ActiveMQJMSConstants.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/ActiveMQJMSConstants.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/ActiveMQJMSConstants.java
index 104645f..fb51608 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/ActiveMQJMSConstants.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/ActiveMQJMSConstants.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.api.jms;
+package org.apache.activemq.artemis.api.jms;
 
 /**
  * Constants for ActiveMQ for property keys used for ActiveMQ specific extensions to JMS.

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/JMSFactoryType.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/JMSFactoryType.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/JMSFactoryType.java
index 8199f46..67a3126 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/JMSFactoryType.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/JMSFactoryType.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.api.jms;
+package org.apache.activemq.artemis.api.jms;
 
 // XXX no javadocs
 public enum JMSFactoryType

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/ConnectionFactoryControl.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/ConnectionFactoryControl.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/ConnectionFactoryControl.java
index 04c6fd4..5046f87 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/ConnectionFactoryControl.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/ConnectionFactoryControl.java
@@ -14,20 +14,20 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.api.jms.management;
+package org.apache.activemq.artemis.api.jms.management;
 
-import org.apache.activemq.api.core.DiscoveryGroupConfiguration;
-import org.apache.activemq.api.core.TransportConfiguration;
-import org.apache.activemq.api.core.management.Operation;
-import org.apache.activemq.api.core.management.Parameter;
+import org.apache.activemq.artemis.api.core.DiscoveryGroupConfiguration;
+import org.apache.activemq.artemis.api.core.TransportConfiguration;
+import org.apache.activemq.artemis.api.core.management.Operation;
+import org.apache.activemq.artemis.api.core.management.Parameter;
 
 /**
  * A ConnectionFactoryControl is used to manage a JMS ConnectionFactory. <br>
  * ActiveMQ JMS ConnectionFactory uses an underlying ClientSessionFactory to connect to ActiveMQ
  * servers. Please refer to the ClientSessionFactory for a detailed description.
  *
- * @see ServerLocator
- * @see ClientSessionFactory
+ * @see org.apache.activemq.artemis.api.core.client.ServerLocator
+ * @see org.apache.activemq.artemis.api.core.client.ClientSessionFactory
  */
 public interface ConnectionFactoryControl
 {
@@ -67,39 +67,39 @@ public interface ConnectionFactoryControl
 
    /**
     * @return whether large messages are compressed
-    * @see ServerLocator#isCompressLargeMessage()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#isCompressLargeMessage()
     */
    boolean isCompressLargeMessages();
 
    void setCompressLargeMessages(boolean compress);
 
    /**
-    * @see ServerLocator#getClientFailureCheckPeriod()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#getClientFailureCheckPeriod()
     */
    long getClientFailureCheckPeriod();
 
    /**
-    * @see ServerLocator#setClientFailureCheckPeriod
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setClientFailureCheckPeriod
     */
    void setClientFailureCheckPeriod(long clientFailureCheckPeriod);
 
    /**
-    * @see ServerLocator#getCallTimeout()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#getCallTimeout()
     */
    long getCallTimeout();
 
    /**
-    * @see ServerLocator#setCallTimeout(long)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setCallTimeout(long)
     */
    void setCallTimeout(long callTimeout);
 
    /**
-    * @see ServerLocator#getCallFailoverTimeout()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#getCallFailoverTimeout()
     */
    long getCallFailoverTimeout();
 
    /**
-    * @see ServerLocator#setCallFailoverTimeout(long)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setCallFailoverTimeout(long)
     */
 
    void setCallFailoverTimeout(long callTimeout);
@@ -108,267 +108,267 @@ public interface ConnectionFactoryControl
     * Returns the batch size (in bytes) between acknowledgements when using DUPS_OK_ACKNOWLEDGE
     * mode.
     *
-    * @see ServerLocator#getAckBatchSize()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#getAckBatchSize()
     * @see javax.jms.Session#DUPS_OK_ACKNOWLEDGE
     */
    int getDupsOKBatchSize();
 
    /**
-    * @see ServerLocator#setAckBatchSize(int)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setAckBatchSize(int)
     */
    void setDupsOKBatchSize(int dupsOKBatchSize);
 
    /**
-    * @see ServerLocator#getConsumerMaxRate()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#getConsumerMaxRate()
     */
    int getConsumerMaxRate();
 
    /**
-    * @see ServerLocator#setConsumerMaxRate(int)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setConsumerMaxRate(int)
     */
    void setConsumerMaxRate(int consumerMaxRate);
 
    /**
-    * @see ServerLocator#getConsumerWindowSize()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#getConsumerWindowSize()
     */
    int getConsumerWindowSize();
 
    /**
-    * @see ServerLocator#setConfirmationWindowSize(int)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setConfirmationWindowSize(int)
     */
    void setConsumerWindowSize(int consumerWindowSize);
 
    /**
-    * @see ServerLocator#getProducerMaxRate()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#getProducerMaxRate()
     */
    int getProducerMaxRate();
 
    /**
-    * @see ServerLocator#setProducerMaxRate(int)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setProducerMaxRate(int)
     */
    void setProducerMaxRate(int producerMaxRate);
 
    /**
-    * @see ServerLocator#getConfirmationWindowSize()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#getConfirmationWindowSize()
     */
    int getConfirmationWindowSize();
 
    /**
-    * @see ServerLocator#setConfirmationWindowSize(int)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setConfirmationWindowSize(int)
     */
    void setConfirmationWindowSize(int confirmationWindowSize);
 
    /**
-    * @see ServerLocator#isBlockOnAcknowledge()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#isBlockOnAcknowledge()
     */
    boolean isBlockOnAcknowledge();
 
    /**
-    * @see ServerLocator#setBlockOnAcknowledge(boolean)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setBlockOnAcknowledge(boolean)
     */
    void setBlockOnAcknowledge(boolean blockOnAcknowledge);
 
    /**
-    * @see ServerLocator#isBlockOnDurableSend()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#isBlockOnDurableSend()
     */
    boolean isBlockOnDurableSend();
 
    /**
-    * @see ServerLocator#setBlockOnDurableSend(boolean)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setBlockOnDurableSend(boolean)
     */
    void setBlockOnDurableSend(boolean blockOnDurableSend);
 
    /**
-    * @see ServerLocator#isBlockOnNonDurableSend()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#isBlockOnNonDurableSend()
     */
    boolean isBlockOnNonDurableSend();
 
    /**
-    * @see ServerLocator#setBlockOnNonDurableSend(boolean)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setBlockOnNonDurableSend(boolean)
     */
    void setBlockOnNonDurableSend(boolean blockOnNonDurableSend);
 
    /**
-    * @see ServerLocator#isPreAcknowledge()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#isPreAcknowledge()
     */
    boolean isPreAcknowledge();
 
    /**
-    * @see ServerLocator#setPreAcknowledge(boolean)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setPreAcknowledge(boolean)
     */
    void setPreAcknowledge(boolean preAcknowledge);
 
 
    /**
-    * @see ServerLocator#getConnectionTTL()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#getConnectionTTL()
     */
    long getConnectionTTL();
 
    /**
-    * @see ServerLocator#setConnectionTTL(long)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setConnectionTTL(long)
     */
    void setConnectionTTL(long connectionTTL);
 
    /**
     * Returns the batch size (in bytes) between acknowledgements when using a transacted session.
     *
-    * @see ServerLocator#getAckBatchSize()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#getAckBatchSize()
     */
    int getTransactionBatchSize();
 
    /**
-    * @see ServerLocator#setAckBatchSize(int)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setAckBatchSize(int)
     */
    void setTransactionBatchSize(int transactionBatchSize);
 
    /**
-    * @see ServerLocator#getMinLargeMessageSize()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#getMinLargeMessageSize()
     */
    int getMinLargeMessageSize();
 
    /**
-    * @see ServerLocator#setMinLargeMessageSize(int)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setMinLargeMessageSize(int)
     */
    void setMinLargeMessageSize(int minLargeMessageSize);
 
    /**
-    * @see ServerLocator#isAutoGroup()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#isAutoGroup()
     */
    boolean isAutoGroup();
 
    /**
-    * @see ServerLocator#setAutoGroup(boolean)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setAutoGroup(boolean)
     */
    void setAutoGroup(boolean autoGroup);
 
    /**
-    * @see ServerLocator#getRetryInterval()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#getRetryInterval()
     */
    long getRetryInterval();
 
    /**
-    * @see ServerLocator#setRetryInterval(long)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setRetryInterval(long)
     */
    void setRetryInterval(long retryInterval);
 
    /**
-    * @see ServerLocator#getRetryIntervalMultiplier()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#getRetryIntervalMultiplier()
     */
    double getRetryIntervalMultiplier();
 
    /**
-    * @see ServerLocator#setRetryIntervalMultiplier(double)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setRetryIntervalMultiplier(double)
     */
    void setRetryIntervalMultiplier(double retryIntervalMultiplier);
 
    /**
-    * @see ServerLocator#getReconnectAttempts()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#getReconnectAttempts()
     */
    int getReconnectAttempts();
 
    /**
-    * @see ServerLocator#setReconnectAttempts(int)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setReconnectAttempts(int)
     */
    void setReconnectAttempts(int reconnectAttempts);
 
    /**
-    * @see ServerLocator#isFailoverOnInitialConnection()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#isFailoverOnInitialConnection()
     */
    boolean isFailoverOnInitialConnection();
 
    /**
-    * @see ServerLocator#setFailoverOnInitialConnection(boolean)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setFailoverOnInitialConnection(boolean)
     */
    void setFailoverOnInitialConnection(boolean failoverOnInitialConnection);
 
 
    /**
-    * @see org.apache.activemq.api.core.client.ServerLocator#getProducerWindowSize()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#getProducerWindowSize()
     */
    int getProducerWindowSize();
 
    /**
-    * @see ServerLocator#setProducerWindowSize(int)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setProducerWindowSize(int)
     */
    void setProducerWindowSize(int producerWindowSize);
 
    /**
-    * @see ServerLocator#isCacheLargeMessagesClient()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#isCacheLargeMessagesClient()
     */
    boolean isCacheLargeMessagesClient();
 
    /**
-    * @see ServerLocator#setCacheLargeMessagesClient(boolean)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setCacheLargeMessagesClient(boolean)
     */
    void setCacheLargeMessagesClient(boolean cacheLargeMessagesClient);
 
    /**
-    * @see ServerLocator#getMaxRetryInterval()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#getMaxRetryInterval()
     */
    long getMaxRetryInterval();
 
    /**
-    * @see ServerLocator#setMaxRetryInterval(long)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setMaxRetryInterval(long)
     */
    void setMaxRetryInterval(long retryInterval);
 
    /**
-    * @see ServerLocator#getScheduledThreadPoolMaxSize()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#getScheduledThreadPoolMaxSize()
     */
    int getScheduledThreadPoolMaxSize();
 
    /**
-    * @see ServerLocator#setScheduledThreadPoolMaxSize(int)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setScheduledThreadPoolMaxSize(int)
     */
    void setScheduledThreadPoolMaxSize(int scheduledThreadPoolMaxSize);
 
    /**
-    * @see ServerLocator#getThreadPoolMaxSize()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#getThreadPoolMaxSize()
     */
    int getThreadPoolMaxSize();
 
    /**
-    * @see ServerLocator#setThreadPoolMaxSize(int)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setThreadPoolMaxSize(int)
     */
    void setThreadPoolMaxSize(int threadPoolMaxSize);
 
    /**
-    * @see ServerLocator#getGroupID()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#getGroupID()
     */
    String getGroupID();
 
    /**
-    * @see ServerLocator#setGroupID(String)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setGroupID(String)
     */
    void setGroupID(String groupID);
 
    /**
-    * @see ServerLocator#getInitialMessagePacketSize()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#getInitialMessagePacketSize()
     */
    int getInitialMessagePacketSize();
 
    /**
-    * @see ServerLocator#isUseGlobalPools()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#isUseGlobalPools()
     */
    boolean isUseGlobalPools();
 
    /**
-    * @see ServerLocator#setUseGlobalPools(boolean)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setUseGlobalPools(boolean)
     */
    void setUseGlobalPools(boolean useGlobalPools);
 
    /**
-    * @see ServerLocator#getConnectionLoadBalancingPolicyClassName()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#getConnectionLoadBalancingPolicyClassName()
     */
    String getConnectionLoadBalancingPolicyClassName();
 
    /**
-    * @see ServerLocator#setConnectionLoadBalancingPolicyClassName(String)
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#setConnectionLoadBalancingPolicyClassName(String)
     */
    void setConnectionLoadBalancingPolicyClassName(String connectionLoadBalancingPolicyClassName);
 
    /**
-    * @see ClientSessionFactory#getStaticConnectors()
+    * @see org.apache.activemq.artemis.api.core.client.ServerLocator#getStaticTransportConfigurations()
     */
    TransportConfiguration[] getStaticConnectors();
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/DestinationControl.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/DestinationControl.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/DestinationControl.java
index 0640d17..7ee35a0 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/DestinationControl.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/DestinationControl.java
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.api.jms.management;
+package org.apache.activemq.artemis.api.jms.management;
 
 import javax.management.MBeanOperationInfo;
 
-import org.apache.activemq.api.core.management.Operation;
-import org.apache.activemq.api.core.management.Parameter;
+import org.apache.activemq.artemis.api.core.management.Operation;
+import org.apache.activemq.artemis.api.core.management.Parameter;
 
 /**
  * A DestinationControl is used to manage a JMS Destination.

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSConnectionInfo.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSConnectionInfo.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSConnectionInfo.java
index c25fd27..38a2aba 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSConnectionInfo.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSConnectionInfo.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.api.jms.management;
+package org.apache.activemq.artemis.api.jms.management;
 
-import org.apache.activemq.utils.json.JSONArray;
-import org.apache.activemq.utils.json.JSONObject;
+import org.apache.activemq.artemis.utils.json.JSONArray;
+import org.apache.activemq.artemis.utils.json.JSONObject;
 
 public class JMSConnectionInfo
 {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSConsumerInfo.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSConsumerInfo.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSConsumerInfo.java
index 40001cb..509b179 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSConsumerInfo.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSConsumerInfo.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.api.jms.management;
+package org.apache.activemq.artemis.api.jms.management;
 
-import org.apache.activemq.utils.json.JSONArray;
-import org.apache.activemq.utils.json.JSONObject;
+import org.apache.activemq.artemis.utils.json.JSONArray;
+import org.apache.activemq.artemis.utils.json.JSONObject;
 
 /**
  * Helper class to create Java Objects from the

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSManagementHelper.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSManagementHelper.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSManagementHelper.java
index 6190ea5..4bf6007 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSManagementHelper.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSManagementHelper.java
@@ -14,20 +14,20 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.api.jms.management;
+package org.apache.activemq.artemis.api.jms.management;
 
 import javax.jms.JMSException;
 import javax.jms.Message;
 
-import org.apache.activemq.api.core.management.ManagementHelper;
-import org.apache.activemq.jms.client.ActiveMQMessage;
+import org.apache.activemq.artemis.api.core.management.ManagementHelper;
+import org.apache.activemq.artemis.jms.client.ActiveMQMessage;
 
 /**
  * Helper class to use JMS messages to manage ActiveMQ server resources.
  */
 public class JMSManagementHelper
 {
-   private static org.apache.activemq.api.core.Message getCoreMessage(final Message jmsMessage)
+   private static org.apache.activemq.artemis.api.core.Message getCoreMessage(final Message jmsMessage)
    {
       if (jmsMessage instanceof ActiveMQMessage == false)
       {
@@ -46,7 +46,7 @@ public class JMSManagementHelper
     * @param attribute the name of the attribute
     * @throws JMSException if an exception occurs while putting the information in the message
     *
-    * @see org.apache.activemq.api.core.management.ResourceNames
+    * @see org.apache.activemq.artemis.api.core.management.ResourceNames
     */
    public static void putAttribute(final Message message, final String resourceName, final String attribute) throws JMSException
    {
@@ -61,7 +61,7 @@ public class JMSManagementHelper
     * @param operationName the name of the operation to invoke on the resource
     * @throws JMSException if an exception occurs while putting the information in the message
     *
-    * @see org.apache.activemq.api.core.management.ResourceNames
+    * @see org.apache.activemq.artemis.api.core.management.ResourceNames
     */
    public static void putOperationInvocation(final Message message,
                                              final String resourceName,
@@ -97,7 +97,7 @@ public class JMSManagementHelper
     * @param parameters the parameters to use to invoke the server resource
     * @throws JMSException if an exception occurs while putting the information in the message
     *
-    * @see org.apache.activemq.api.core.management.ResourceNames
+    * @see org.apache.activemq.artemis.api.core.management.ResourceNames
     */
    public static void putOperationInvocation(final Message message,
                                              final String resourceName,

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSQueueControl.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSQueueControl.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSQueueControl.java
index 586f5c2..a128d83 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSQueueControl.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSQueueControl.java
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.api.jms.management;
+package org.apache.activemq.artemis.api.jms.management;
 
 import java.util.Map;
 
 import javax.management.MBeanOperationInfo;
 
-import org.apache.activemq.api.core.management.Operation;
-import org.apache.activemq.api.core.management.Parameter;
+import org.apache.activemq.artemis.api.core.management.Operation;
+import org.apache.activemq.artemis.api.core.management.Parameter;
 
 /**
  * A JMSQueueControl is used to manage a JMS queue.

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSServerControl.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSSessionInfo.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSSessionInfo.java
index baf2b19..7e76c7b 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSSessionInfo.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSSessionInfo.java
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.api.jms.management;
+package org.apache.activemq.artemis.api.jms.management;
 
-import org.apache.activemq.utils.json.JSONArray;
-import org.apache.activemq.utils.json.JSONException;
-import org.apache.activemq.utils.json.JSONObject;
+import org.apache.activemq.artemis.utils.json.JSONArray;
+import org.apache.activemq.artemis.utils.json.JSONException;
+import org.apache.activemq.artemis.utils.json.JSONObject;
 
 public class JMSSessionInfo
 {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/SubscriptionInfo.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/SubscriptionInfo.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/SubscriptionInfo.java
index 578ba32..131f001 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/SubscriptionInfo.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/SubscriptionInfo.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.api.jms.management;
+package org.apache.activemq.artemis.api.jms.management;
 
-import org.apache.activemq.utils.json.JSONArray;
-import org.apache.activemq.utils.json.JSONObject;
+import org.apache.activemq.artemis.utils.json.JSONArray;
+import org.apache.activemq.artemis.utils.json.JSONObject;
 
 /**
  * Helper class to create Java Objects from the

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/TopicControl.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/TopicControl.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/TopicControl.java
index 917a75b..c19bcfb 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/TopicControl.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/TopicControl.java
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.api.jms.management;
+package org.apache.activemq.artemis.api.jms.management;
 
 import java.util.Map;
 
 import javax.management.MBeanOperationInfo;
 
-import org.apache.activemq.api.core.management.Operation;
-import org.apache.activemq.api.core.management.Parameter;
+import org.apache.activemq.artemis.api.core.management.Operation;
+import org.apache.activemq.artemis.api.core.management.Parameter;
 
 /**
  * A TopicControl is used to manage a JMS Topic.

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/package-info.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/package-info.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/package-info.java
index a50295b..01539a6 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/package-info.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/package-info.java
@@ -14,5 +14,5 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.api.jms.management;
+package org.apache.activemq.artemis.api.jms.management;
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/package-info.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/package-info.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/package-info.java
index ba13daa..14e88b5 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/package-info.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/package-info.java
@@ -14,5 +14,5 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.api.jms;
+package org.apache.activemq.artemis.api.jms;
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQBytesMessage.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQBytesMessage.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQBytesMessage.java
index 1506a2b..ed38b1c 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQBytesMessage.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQBytesMessage.java
@@ -14,44 +14,44 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.jms.client;
+package org.apache.activemq.artemis.jms.client;
 
 import javax.jms.BytesMessage;
 import javax.jms.JMSException;
 import javax.jms.MessageEOFException;
 import javax.jms.MessageFormatException;
 
-import org.apache.activemq.api.core.ActiveMQBuffer;
-import org.apache.activemq.api.core.ActiveMQException;
-import org.apache.activemq.api.core.Message;
-import org.apache.activemq.api.core.client.ClientMessage;
-import org.apache.activemq.api.core.client.ClientSession;
-import org.apache.activemq.core.message.impl.MessageImpl;
-
-import static org.apache.activemq.reader.BytesMessageUtil.bytesMessageReset;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesReadBoolean;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesReadByte;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesReadBytes;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesReadChar;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesReadDouble;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesReadFloat;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesReadInt;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesReadLong;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesReadShort;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesReadUTF;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesReadUnsignedByte;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesReadUnsignedShort;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesWriteBoolean;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesWriteByte;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesWriteBytes;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesWriteChar;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesWriteDouble;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesWriteFloat;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesWriteInt;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesWriteLong;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesWriteObject;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesWriteShort;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesWriteUTF;
+import org.apache.activemq.artemis.api.core.ActiveMQBuffer;
+import org.apache.activemq.artemis.api.core.ActiveMQException;
+import org.apache.activemq.artemis.api.core.Message;
+import org.apache.activemq.artemis.api.core.client.ClientMessage;
+import org.apache.activemq.artemis.api.core.client.ClientSession;
+import org.apache.activemq.artemis.core.message.impl.MessageImpl;
+
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesMessageReset;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesReadBoolean;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesReadByte;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesReadBytes;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesReadChar;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesReadDouble;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesReadFloat;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesReadInt;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesReadLong;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesReadShort;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesReadUTF;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesReadUnsignedByte;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesReadUnsignedShort;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesWriteBoolean;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesWriteByte;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesWriteBytes;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesWriteChar;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesWriteDouble;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesWriteFloat;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesWriteInt;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesWriteLong;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesWriteObject;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesWriteShort;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesWriteUTF;
 
 /**
  * ActiveMQ implementation of a JMS {@link BytesMessage}.
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSServerControl.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSServerControl.java
index 56297ee..739f647 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSServerControl.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSServerControl.java
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.api.jms.management;
+package org.apache.activemq.artemis.api.jms.management;
 
 import javax.management.MBeanOperationInfo;
 
-import org.apache.activemq.api.core.management.Operation;
-import org.apache.activemq.api.core.management.Parameter;
+import org.apache.activemq.artemis.api.core.management.Operation;
+import org.apache.activemq.artemis.api.core.management.Parameter;
 
 /**
  * A JMSSserverControl is used to manage ActiveMQ JMS server.
@@ -148,8 +148,8 @@ public interface JMSServerControl
     * The ConnectionFactory is bound to JNDI for all the specified bindings Strings.
     * <br>
     * {@code liveConnectorsTransportClassNames}  are the class names
     * of the {@link org.apache.activemq.spi.core.remoting.ConnectorFactory} to connect to the live servers
     * and {@code liveConnectorTransportParams}  are Map&lt;String, Object&gt; for the corresponding {@link org.apache.activemq.api.core.TransportConfiguration}'s parameters.
     */
    void createConnectionFactory(String name,
                                 boolean ha,

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSSessionInfo.java
----------------------------------------------------------------------
@@ -148,8 +148,8 @@ public interface JMSServerControl
     * <br>
     * {@code liveConnectorsTransportClassNames}  are the class names
-    * of the {@link org.apache.activemq.spi.core.remoting.ConnectorFactory} to connect to the live servers
-    * and {@code liveConnectorTransportParams}  are Map&lt;String, Object&gt; for the corresponding {@link org.apache.activemq.api.core.TransportConfiguration}'s parameters.
+    * of the {@link org.apache.activemq.artemis.spi.core.remoting.ConnectorFactory} to connect to the live servers
+    * and {@code liveConnectorTransportParams}  are Map&lt;String, Object&gt; for the corresponding {@link org.apache.activemq.artemis.api.core.TransportConfiguration}'s parameters.
     */
    void createConnectionFactory(String name,